@@ -15,14 +15,12 @@
 class QWidget;
 class Worksheet;
 class WorksheetView;
-class SarchBar;
 class SearchBar;
 class ScriptEditorWidget;
 class KAboutData;
 class QAction;
 class KToggleAction;
 class KSelectAction;
-class QProgressDialog;
 
 namespace Cantor{
     class PanelPluginHandler;
@@ -42,7 +40,7 @@ public:
     /**
      * Default constructor
      */
-    CantorPart(QWidget *parentWidget,QObject *parent, const QVariantList &args);
+    CantorPart(QWidget* , QObject*, const QVariantList& args);
 
     /**
      * Destructor
@@ -54,12 +52,12 @@ public:
      * A shell will use this to inform this Part if it should act
      * read-only
      */
-    void setReadWrite(bool rw) override;
+    void setReadWrite(bool) override;
 
     /**
      * Reimplemented to disable and enable Save action
      */
-    void setModified(bool modified) override;
+    void setModified(bool) override;
 
     KAboutData& createAboutData();
 
@@ -67,11 +65,11 @@ public:
 
 Q_SIGNALS:
     void setCaption(const QString& caption, const QIcon& icon);
-    void showHelp(const QString& help);
+    void showHelp(const QString&);
     void hierarchyChanged(QStringList, QStringList, QList<int>);
     void hierarhyEntryNameChange(QString name, QString searchName, int depth);
-    void worksheetSave(const QUrl& url);
-    void setBackendName(const QString& name);
+    void worksheetSave(const QUrl&);
+    void setBackendName(const QString&);
     void requestScrollToHierarchyEntry(QString);
     void settingsChanges();
     void requestDocumentation(const QString& keyword);
@@ -94,8 +92,7 @@ protected:
      * Called when this part becomes the active one,
      * or if it looses activity
      **/
-    void guiActivateEvent( KParts::GUIActivateEvent * event ) override;
-
+    void guiActivateEvent(KParts::GUIActivateEvent*) override;
 
     void loadAssistants();
     void adjustGuiToSession();
@@ -108,27 +105,27 @@ protected Q_SLOTS:
     void exportToLatex();
     void evaluateOrInterrupt();
     void restartBackend();
-    void zoomValueEdited(const QString& text);
-    void updateZoomWidgetValue(double zoom);
-    void enableTypesetting(bool enable);
+    void zoomValueEdited(const QString&);
+    void updateZoomWidgetValue(double);
+    void enableTypesetting(bool);
     void showBackendHelp();
     void print();
     void printPreview();
 
-    void worksheetStatusChanged(Cantor::Session::Status stauts);
-    void showSessionError(const QString& error);
+    void worksheetStatusChanged(Cantor::Session::Status);
+    void showSessionError(const QString&);
     void worksheetSessionLoginStarted();
     void worksheetSessionLoginDone();
     void initialized();
 
-    void runCommand(const QString& value);
+    void runCommand(const QString&);
 
     void runAssistant();
     void publishWorksheet();
 
-    void showScriptEditor(bool show);
+    void showScriptEditor(bool);
     void scriptEditorClosed();
-    void runScript(const QString& file);
+    void runScript(const QString&);
 
     void showSearchBar();
     void showExtendedSearchBar();
@@ -139,11 +136,11 @@ protected Q_SLOTS:
     /** sets the status message, or cached it, if the StatusBar is blocked.
      *  Use this method instead of "emit setStatusBarText"
      */
-    void setStatusMessage(const QString& message);
+    void setStatusMessage(const QString&);
     /** Shows an important status message. It makes sure the message is displayed,
      *  by blocking the statusbarText for 3 seconds
      */
-    void showImportantStatusMessage(const QString& message);
+    void showImportantStatusMessage(const QString&);
     /** Blocks the StatusBar for new messages, so the currently shown one won't be overridden
      */
     void blockStatusBar();
@@ -153,20 +150,18 @@ protected Q_SLOTS:
     void unblockStatusBar();
 
 private:
-    Worksheet *m_worksheet;
-    WorksheetView *m_worksheetview;
-    SearchBar *m_searchBar;
+    Worksheet* m_worksheet{nullptr};
+    WorksheetView* m_worksheetview{nullptr};
+    SearchBar* m_searchBar{nullptr};
     QPointer<ScriptEditorWidget> m_scriptEditor;
 
-    QProgressDialog* m_initProgressDlg;
-    bool m_showProgressDlg;
-    QAction * m_evaluate;
-    QAction * m_restart;
+    QAction* m_evaluate;
+    QAction* m_restart;
     KSelectAction* m_zoom;
-    QAction* m_currectZoomAction;
-    QAction * m_save;
-    QAction * m_findNext;
-    QAction * m_findPrev;
+    QAction* m_currectZoomAction{nullptr};
+    QAction* m_save;
+    QAction* m_findNext;
+    QAction* m_findPrev;
     KToggleAction* m_typeset;
     KToggleAction* m_highlight;
     KToggleAction* m_completion;
@@ -176,8 +171,8 @@ private:
     QVector<QAction*> m_editActions;
 
     QString m_cachedStatusMessage;
-    bool m_statusBarBlocked;
-    unsigned int m_sessionStatusCounter;
+    bool m_statusBarBlocked{false};
+    unsigned int m_sessionStatusCounter{0};
 
 private Q_SLOTS:
     void documentationRequested(const QString&);
